==> maj-0.1.tar.gz: maj-0.1/maj.sh <==
#!/bin/sh
#
#	$Id: maj.sh,v 1.1 2009/11/03 14:06:53 mattieu Exp $
#
# Copyright (c) 2007-2009 Mattieu Baptiste <mattieu.b@free.fr>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
# 

umask 0022

unset ARCH BRANCH VERSION KERNCONF WITHX

ARCH=`machine`

if [ -f /etc/mk.conf ]; then
	if [ "`id -u`" -ne "0" ]; then
		SUDO=`grep -s '^SUDO' /etc/mk.conf | sed -e "s/^SUDO=//"`
	fi
	BSDSRCDIR=`grep -s '^BSDSRCDIR' /etc/mk.conf | sed -e "s/^BSDSRCDIR=//"`
	XSRCDIR=`grep -s '^XSRCDIR' /etc/mk.conf | sed -e "s/^XSRCDIR=//"`
	BSDOBJDIR=`grep -s '^BSDOBJDIR' /etc/mk.conf | sed -e "s/^BSDOBJDIR=//"`
	XOBJDIR=`grep -s '^XOBJDIR' /etc/mk.conf | sed -e "s/^XOBJDIR=//"`
	PORTSDIR=`grep -s '^PORTSDIR' /etc/mk.conf | sed -e "s/^PORTSDIR=//"`
fi

if [ "${BSDSRCDIR}" = "" ]; then
	BSDSRCDIR="/usr/src"
fi
if [ "${XSRCDIR}" = "" ]; then
	XSRCDIR="/usr/xenocara"
fi
if [ "${BSDOBJDIR}" = "" ]; then
	BSDOBJDIR="/usr/obj"
fi
if [ "${XOBJDIR}" = "" ]; then
	XOBJDIR="/usr/xobj"
fi
if [ "${PORTSDIR}" = "" ]; then
	PORTSDIR="/usr/ports"
fi

BRANCH=`grep '^OpenBSD' /etc/motd | awk '{print $2}' | \
	sed -e "s/\`uname -r\`//g"`
if [ "${BRANCH}" = "-current" -o "${BRANCH}" = "-beta" ]; then
	VERSION=""
elif [ "${BRANCH}" = "-stable" -o "${BRANCH}" = "" ]; then
	VERSION="-rOPENBSD_"`uname -r | sed -e "s/\./_/"`
fi

if [ "$(sysctl -n hw.ncpufound)" = "1" ]; then
	KERNCONF="GENERIC"
else
	KERNCONF="GENERIC.MP"
fi

if [ -x /usr/X11R6/bin/startx ]; then
	WITHX="YES"
fi

usage() {
	echo "usage: ${0##*/} [-irtV] [-g tree] [-u tree] [-c component] [-k component]" >&2
	echo "\t[-d cvsroot] [-D destdir] [-R releasedir] [-C configfile] [-S cvstree]"
	exit 1
}

get_x() {
	echo "getting ${1}..."
	case "${1}" in
	src)
		cd ${BSDSRCDIR} && cvs -qd ${CVSROOT} get ${VERSION} -P ${1}
		;;
	xenocara)
		cd ${XSRCDIR} && cvs -qd ${CVSROOT} get ${VERSION} -P ${1}
		;;
	ports)
		cd ${PORTSDIR} && cvs -qd ${CVSROOT} get ${VERSION} -P ${1}
		;;
	esac
}

up_x() {
	echo "updating ${1}..."
	case "${1}" in
	src)
		cd ${BSDSRCDIR} && cvs -d ${CVSROOT} -q up ${VERSION} -Pd
		;;
	xenocara)
		cd ${XSRCDIR} && cvs -d ${CVSROOT} -q up ${VERSION} -Pd
		;;
	ports)
		cd ${PORTSDIR} && cvs -d ${CVSROOT} -q up ${VERSION} -Pd
		;;
	esac
}

rm_x() {
	echo "cleaning ${1}..."
	case "${1}" in
	kobj)
		cd ${BSDSRCDIR}/sys/arch/${ARCH}/compile && rm -rf ${KERNCONF}
		;;
	bsdobj)
		cd ${BSDOBJDIR} && mkdir -p .old && ${SUDO} mv * .old && ${SUDO} rm -rf .old &
		;;
	xobj)
		cd ${XOBJDIR} && mkdir -p .old && ${SUDO} mv * .old && ${SUDO} rm -rf .old &
		;;
	esac
}

comp_x() {
	time=`date +"%Y-%m-%d %T"`
	case ${1} in
	kernel)
		rm_x kobj
		cd ${BSDSRCDIR}/sys/arch/${ARCH}/conf
		/usr/sbin/config ${KERNCONF}
		cd ${BSDSRCDIR}/sys/arch/${ARCH}/compile/${KERNCONF}
		make clean && make depend && make
		;;
	uland)
		rm_x bsdobj
		cd ${BSDSRCDIR} && nice make obj
		cd ${BSDSRCDIR}/etc && env DESTDIR=/ ${SUDO} make distrib-dirs
		cd ${BSDSRCDIR} && nice make SUDO=${SUDO} build
		;;
	xenocara)
		rm_x xobj
		cd ${XSRCDIR}
		make bootstrap
		make obj
		make build
		;;
	esac
	if [ "${timeopt}" -eq "1" ]; then
		echo "Started:"'\t'${time}
		echo -n "Ended:"'\t''\t'
		date +"%Y-%m-%d %T"
	fi
}

install_kernel() {
	cd ${BSDSRCDIR}/sys/arch/${ARCH}/compile/${KERNCONF}
	${SUDO} make install
}

make_release() {
	if [ ! -d "${DESTDIR}" ]; then
		echo " *** Error: the destination directory doesn't exist"
		exit 1
	fi
	if [ ! -d "${RELEASEDIR}" ]; then
		echo " *** Error: the release directory doesn't exist"
		exit 1
	fi
	export DESTDIR
	export RELEASEDIR
	time=`date +"%Y-%m-%d %T"`
	${SUDO} sh -c "test -d ${DESTDIR} && mv ${DESTDIR} ${DESTDIR}- && rm -rf ${DESTDIR}-"
	${SUDO} mkdir -p ${DESTDIR} ${RELEASEDIR}
	${SUDO} sh -c "cd ${BSDSRCDIR}/etc && nice make release"
	${SUDO} sh -c "cd ${BSDSRCDIR}/distrib/sets && sh checkflist"
	if [ "$WITHX" = "YES" ]; then
		cd ${XSRCDIR}
		${SUDO} sh -c "test -d ${DESTDIR} && mv ${DESTDIR} ${DESTDIR}- && rm -rf ${DESTDIR}-"
		${SUDO} mkdir -p ${DESTDIR} ${RELEASEDIR}
		${SUDO} nice make release
	fi
	if [ "${timeopt}" -eq "1" ]; then
		echo "Started:"'\t'${time}
		echo -n "Ended:"'\t''\t'
		date +"%Y-%m-%d %T"
	fi
}

while getopts ':g:u:c:k:d:D:R:irtV' arg; do
	case ${arg} in
	g)
		if [ "${OPTARG}" == "src" -o "${OPTARG}" == "xenocara" -o "${OPTARG}" == "ports" -o "${OPTARG}" == "all" ]; then
			getopt=${OPTARG}
		else
			echo " *** Error: the tree to get is not valid"
			exit 1
		fi
		;;
	u)
		if [ "${OPTARG}" == "src" -o "${OPTARG}" == "xenocara" -o "${OPTARG}" == "ports" -o "${OPTARG}" == "all" ]; then
			updateopt=${OPTARG}
		else
			echo " *** Error: the tree to update is not valid"
			exit 1
		fi
		;;
	c)
		if [ "${OPTARG}" == "kernel" -o "${OPTARG}" == "uland" -o "${OPTARG}" == "xenocara" ]; then
			compileopt=${OPTARG}
		else
			echo " *** Error: the component to compile is not valid"
			exit 1
		fi
		;;
	k)
		if [ "${OPTARG}" == "kobj" -o "${OPTARG}" == "bsdobj" -o "${OPTARG}" == "xobj" -o "${OPTARG}" == "all" ]; then
			compileopt=${OPTARG}
		else
			echo " *** Error: the component to clean is not valid"
			exit 1
		fi
		;;
	i)
		installopt=1
		;;
	r)
		releaseopt=1
		;;
	t)	timeopt=1
		;;
	d)
		if echo -n "${OPTARG}" | grep '^anoncvs\@.*:/cvs$' > /dev/null 2>&1 ; then
			CVSROOT=${OPTARG}
		else
			echo " *** Error: your anonymous CVS is not valid"
			exit 1
		fi
		;;
	D)
		if [ -d "${OPTARG}" ]; then
			DESTDIR=${OPTARG}
		else
			echo " *** Error: the destination directory doesn't exist"
			exit 1
		fi
		;;
	R)
		if [ -d "${OPTARG}" ]; then
			RELEASEDIR=${OPTARG}
		else
			echo " *** Error: the release directory doesn't exist"
			exit 1
		fi
		;;
	C)
		if [ -f "${BSDSRCDIR}/sys/arch/${ARCH}/conf/${OPTARG}" ]; then
			KERNCONF=${OPTARG}
		else
			echo " *** Error: the kernel configuration file doesn't exist"
			exit 1
		fi
		;;
	V)
		VERSION=""
		;;
	\?)
		usage
		;;
	esac
done

if [ "${OPTIND}" -lt "2" ]; then
	usage
fi

if [ "${getopt}" ]; then
	case ${getopt} in
	src | ports | xenocara)
		get_x ${getopt}
		;;
	all)
		get_x src
		if [ "${WITHX}" = "YES" ]; then
			get_x xenocara
		fi
		get_x ports
		;;
	esac
fi

if [ "${updateopt}" ]; then
	case ${updateopt} in
	src | ports | xenocara)
		up_x ${updateopt}
		;;
	all)
		up_x src
		if [ "${WITHX}" = "YES" ]; then
			up_x xenocara
		fi
		up_x ports
		;;
	esac
fi

if [ "${cleanopt}" ]; then
	case ${cleanopt} in
	kobj | bsdobj | xobj)
		rm_x ${cleanopt}
		;;
	all)
		rm_x kobj
		rm_x bsdobj
		if [ "${WITHX}" = "YES" ]; then
			rm_x xobj
		fi
		;;
	esac
fi

if [ "${compileopt}" ]; then
	case ${compileopt} in
	kernel)
		comp_x kernel
		;;
	uland)
		comp_x uland
		;;
	xenocara)
		comp_x xenocara
		;;
	esac
fi

if [ "${installopt}" -eq "1" ]; then
	install_kernel
fi

if [ "${releaseopt}" -eq "1" ]; then
	make_release
fi

==> maj-0.2.tar.gz: maj-0.2/maj.sh <==
#!/bin/sh
#
#	$Id: maj.sh,v 1.6 2009/11/13 11:34:32 mattieu Exp $
#
# Copyright (c) 2007-2009 Mattieu Baptiste <mattieu.b@free.fr>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
# 

umask 0022

unset ARCH BRANCH JOBOPT KERNCONF VERSION WITHX

ARCH=`machine`

if [ -f /etc/mk.conf ]; then
	if [ "`id -u`" -ne "0" ]; then
		SUDO=`grep -s '^SUDO' /etc/mk.conf | sed -e "s/^SUDO=//"`
	fi
	BSDSRCDIR=`grep -s '^BSDSRCDIR' /etc/mk.conf | sed -e "s/^BSDSRCDIR=//"`
	XSRCDIR=`grep -s '^XSRCDIR' /etc/mk.conf | sed -e "s/^XSRCDIR=//"`
	BSDOBJDIR=`grep -s '^BSDOBJDIR' /etc/mk.conf | sed -e "s/^BSDOBJDIR=//"`
	XOBJDIR=`grep -s '^XOBJDIR' /etc/mk.conf | sed -e "s/^XOBJDIR=//"`
	PORTSDIR=`grep -s '^PORTSDIR' /etc/mk.conf | sed -e "s/^PORTSDIR=//"`
fi

if [ "${BSDSRCDIR}" = "" ]; then
	BSDSRCDIR="/usr/src"
fi
if [ "${XSRCDIR}" = "" ]; then
	XSRCDIR="/usr/xenocara"
fi
if [ "${BSDOBJDIR}" = "" ]; then
	BSDOBJDIR="/usr/obj"
fi
if [ "${XOBJDIR}" = "" ]; then
	XOBJDIR="/usr/xobj"
fi
if [ "${PORTSDIR}" = "" ]; then
	PORTSDIR="/usr/ports"
fi

BRANCH=`grep '^OpenBSD' /etc/motd | awk '{print $2}' | \
	sed -e "s/\`uname -r\`//g"`
if [ "${BRANCH}" = "-current" -o "${BRANCH}" = "-beta" ]; then
	VERSION=""
elif [ "${BRANCH}" = "-stable" -o "${BRANCH}" = "" ]; then
	VERSION="-rOPENBSD_"`uname -r | sed -e "s/\./_/"`
fi

if [ "$(sysctl -n hw.ncpufound)" = "1" ]; then
	KERNCONF="GENERIC"
else
	KERNCONF="GENERIC.MP"
fi

if [ -x /usr/X11R6/bin/startx ]; then
	WITHX="YES"
fi

usage() {
	echo "usage: ${0##*/} [-irtVX] [-g tree] [-u tree] [-c component] [-k component]" >&2
	echo "\t[-j njobs] [-d cvsroot] [-D destdir] [-R releasedir] [-C configfile]" >&2
	echo "\t[-S cvstree]" >&2
	exit 1
}

get_x() {
	echo "getting ${1}..."
	case "${1}" in
	src)
		cd ${BSDSRCDIR} && cvs -qd ${CVSROOT} get ${VERSION} -P ${1}
		;;
	xenocara)
		cd ${XSRCDIR} && cvs -qd ${CVSROOT} get ${VERSION} -P ${1}
		;;
	ports)
		cd ${PORTSDIR} && cvs -qd ${CVSROOT} get ${VERSION} -P ${1}
		;;
	esac
}

up_x() {
	echo "updating ${1}..."
	case "${1}" in
	src)
		cd ${BSDSRCDIR} && cvs -d ${CVSROOT} -q up ${VERSION} -Pd
		;;
	xenocara)
		cd ${XSRCDIR} && cvs -d ${CVSROOT} -q up ${VERSION} -Pd
		;;
	ports)
		cd ${PORTSDIR} && cvs -d ${CVSROOT} -q up ${VERSION} -Pd
		;;
	esac
}

rm_x() {
	echo "cleaning ${1}..."
	case "${1}" in
	kobj)
		cd ${BSDSRCDIR}/sys/arch/${ARCH}/compile && rm -rf ${KERNCONF}
		;;
	bsdobj)
		cd ${BSDOBJDIR} && mkdir -p .old && ${SUDO} mv * .old && ${SUDO} rm -rf .old &
		;;
	xobj)
		cd ${XOBJDIR} && mkdir -p .old && ${SUDO} mv * .old && ${SUDO} rm -rf .old &
		;;
	esac
}

comp_x() {
	case ${1} in
	kernel)
		rm_x kobj
		cd ${BSDSRCDIR}/sys/arch/${ARCH}/conf
		/usr/sbin/config ${KERNCONF}
		cd ${BSDSRCDIR}/sys/arch/${ARCH}/compile/${KERNCONF}
		make ${JOBOPT} clean && make ${JOBOPT} depend && make ${JOBOPT}
		;;
	uland)
		rm_x bsdobj
		cd ${BSDSRCDIR} && nice make ${JOBOPT} obj
		cd ${BSDSRCDIR}/etc && env DESTDIR=/ ${SUDO} make ${JOBOPT} distrib-dirs
		cd ${BSDSRCDIR} && nice make ${JOBOPT} SUDO=${SUDO} build
		;;
	xenocara)
		rm_x xobj
		cd ${XSRCDIR}
		make ${JOBOPT} bootstrap
		make ${JOBOPT} obj
		make ${JOBOPT} build
		;;
	esac
}

install_kernel() {
	cd ${BSDSRCDIR}/sys/arch/${ARCH}/compile/${KERNCONF}
	${SUDO} make install
}

make_release() {
	if [ ! -d "${DESTDIR}" ]; then
		echo " *** Error: the destination directory doesn't exist"
		exit 1
	fi
	if [ ! -d "${RELEASEDIR}" ]; then
		echo " *** Error: the release directory doesn't exist"
		exit 1
	fi
	export DESTDIR
	export RELEASEDIR
	${SUDO} sh -c "test -d ${DESTDIR} && mv ${DESTDIR} ${DESTDIR}- && rm -rf ${DESTDIR}-"
	${SUDO} mkdir -p ${DESTDIR} ${RELEASEDIR}
	${SUDO} sh -c "cd ${BSDSRCDIR}/etc && nice make {JOBOPT} release"
	${SUDO} sh -c "cd ${BSDSRCDIR}/distrib/sets && sh checkflist"
	if [ "$WITHX" ]; then
		cd ${XSRCDIR}
		${SUDO} sh -c "test -d ${DESTDIR} && mv ${DESTDIR} ${DESTDIR}- && rm -rf ${DESTDIR}-"
		${SUDO} mkdir -p ${DESTDIR} ${RELEASEDIR}
		if [ "${JOBS}" == "" ]; then
			${SUDO} nice make release
		else
			${SUDO} nice make -j ${JOBS} release
		fi
	fi
}

while getopts ':g:u:c:k:d:D:R:j:irtVX' arg; do
	case ${arg} in
	C)
		if [ -f "${BSDSRCDIR}/sys/arch/${ARCH}/conf/${OPTARG}" ]; then
			KERNCONF=${OPTARG}
		else
			echo " *** Error: the kernel configuration file doesn't exist"
			exit 1
		fi
		;;
	c)
		if [ "${OPTARG}" == "kernel" -o "${OPTARG}" == "uland" -o "${OPTARG}" == "xenocara" -o "${OPTARG}" == "all" ]; then
			compileopt=${OPTARG}
		else
			echo " *** Error: the component to compile is not valid"
			exit 1
		fi
		;;
	D)
		if [ -d "${OPTARG}" ]; then
			DESTDIR=${OPTARG}
		else
			echo " *** Error: the destination directory doesn't exist"
			exit 1
		fi
		;;
	d)
		if echo -n "${OPTARG}" | grep '^anoncvs\@.*:/cvs$' > /dev/null 2>&1 ; then
			CVSROOT=${OPTARG}
		else
			echo " *** Error: your anonymous CVS is not valid"
			exit 1
		fi
		;;
	g)
		if [ "${OPTARG}" == "src" -o "${OPTARG}" == "xenocara" -o "${OPTARG}" == "ports" -o "${OPTARG}" == "all" ]; then
			getopt=${OPTARG}
		else
			echo " *** Error: the tree to get is not valid"
			exit 1
		fi
		;;
	i)
		installopt=1
		;;
	j)
		if [ ${OPTARG} -gt "0" ]; then
			JOBOPT="-j ${OPTARG}"
		else
			echo " *** Error: please provide more than one job to make"
			exit 1
		fi
		;;
	k)
		if [ "${OPTARG}" == "kobj" -o "${OPTARG}" == "bsdobj" -o "${OPTARG}" == "xobj" -o "${OPTARG}" == "all" ]; then
			cleanopt=${OPTARG}
		else
			echo " *** Error: the component to clean is not valid"
			exit 1
		fi
		;;
	R)
		if [ -d "${OPTARG}" ]; then
			RELEASEDIR=${OPTARG}
		else
			echo " *** Error: the release directory doesn't exist"
			exit 1
		fi
		;;
	r)
		releaseopt=1
		;;
	t)	timeopt=1
		;;
	u)
		if [ "${OPTARG}" == "src" -o "${OPTARG}" == "xenocara" -o "${OPTARG}" == "ports" -o "${OPTARG}" == "all" ]; then
			updateopt=${OPTARG}
		else
			echo " *** Error: the tree to update is not valid"
			exit 1
		fi
		;;
	V)
		VERSION=""
		;;
	X)
		WITHX="YES"
		;;
	\?)
		usage
		;;
	esac
done

if [ "${OPTIND}" -lt "2" ]; then
	usage
fi

if [ "${getopt}" ]; then
	case ${getopt} in
	src | ports | xenocara)
		get_x ${getopt}
		;;
	all)
		get_x src
		if [ "${WITHX}" ]; then
			get_x xenocara
		fi
		get_x ports
		;;
	esac
fi

if [ "${updateopt}" ]; then
	case ${updateopt} in
	src | ports | xenocara)
		up_x ${updateopt}
		;;
	all)
		up_x src
		if [ "${WITHX}" ]; then
			up_x xenocara
		fi
		up_x ports
		;;
	esac
fi

if [ "${cleanopt}" ]; then
	case ${cleanopt} in
	kobj | bsdobj | xobj)
		rm_x ${cleanopt}
		;;
	all)
		rm_x kobj
		rm_x bsdobj
		if [ "${WITHX}" ]; then
			rm_x xobj
		fi
		;;
	esac
fi

if [ "${compileopt}" ]; then
	time=`date +"%Y-%m-%d %T"`
	case ${compileopt} in
	kernel | uland | xenocara)
		comp_x ${compileopt}
		;;
	all)
		comp_x kernel
		install_kernel
		comp_x uland
		if [ "${WITHX}" ]; then
			comp_x xenocara
		fi
		;;
	esac
	if [ "${timeopt}" -eq "1" ]; then
		echo "Started:"'\t'${time}
		echo -n "Ended:"'\t''\t'
		date +"%Y-%m-%d %T"
	fi
fi

if [ "${installopt}" -eq "1" ]; then
	install_kernel
fi

if [ "${releaseopt}" -eq "1" ]; then
	make_release
fi
